.. _codes:

Source codes
============


.. _code_bpm:

beampy.bpm
----------

.. literalinclude:: ../beampy/bpm.py


.. _code_interface:

beampy.interface
----------------

.. literalinclude:: ../beampy/interface.py


.. _code_user_interface:

beampy.user\_interface
----------------------

.. literalinclude:: ../beampy/user_interface.py


.. _code_examples:

beampy.examples
----------------------

.. literalinclude:: ../beampy/examples.py